@@ -1,13 +1,18 @@
 #!/usr/bin/env bash
 # script to install libzmq/libsodium for use in wheels
 set -ex
-LIBSODIUM_VERSION="1.0.18"
-
-LIBZMQ_VERSION="$(python3 -m buildutils.bundle)"
+LIBSODIUM_VERSION=$(python buildutils/bundle.py libsodium)
+LIBZMQ_VERSION=$(python buildutils/bundle.py)
+PYZMQ_DIR="$PWD"
+LICENSE_DIR="$PYZMQ_DIR/licenses"
+test -d "$LICENSE_DIR" || mkdir "$LICENSE_DIR"
 
 if [[ "$(uname)" == "Darwin" ]]; then
+    # need LT_MULTI_MODULE or libtool will strip out
+    # all multi-arch symbols at the last step
+    export LT_MULTI_MODULE=1
     ARCHS="x86_64"
-    case "${CIBW_ARCHS_MACOS:-auto}" in
+    case "${CIBW_ARCHS_MACOS:-${CIBW_ARCHS:-auto}}" in
         "universal2")
             ARCHS="x86_64 arm64"
             ;;
@@ -25,21 +30,25 @@ if [[ "$(uname)" == "Darwin" ]]; then
             ;;
     esac
     echo "building libzmq for mac ${ARCHS}"
+    export CXX="${CC:-clang++}"
     for arch in ${ARCHS}; do
+        # seem to need ARCH in CXX for libtool
+        export CXX="${CXX} -arch ${arch}"
         export CFLAGS="-arch ${arch} ${CFLAGS:-}"
         export CXXFLAGS="-arch ${arch} ${CXXFLAGS:-}"
         export LDFLAGS="-arch ${arch} ${LDFLAGS:-}"
     done
 fi
 
-PREFIX="${PREFIX:-/usr/local}"
+PREFIX="${ZMQ_PREFIX:-/usr/local}"
 
 curl -L -O "https://download.libsodium.org/libsodium/releases/libsodium-${LIBSODIUM_VERSION}.tar.gz"
 
 curl -L -O "https://github.com/zeromq/libzmq/releases/download/v${LIBZMQ_VERSION}/zeromq-${LIBZMQ_VERSION}.tar.gz"
 
 tar -xzf libsodium-${LIBSODIUM_VERSION}.tar.gz
-cd libsodium-${LIBSODIUM_VERSION}
+cd libsodium-*/
+cp LICENSE "${LICENSE_DIR}/LICENSE.libsodium.txt"
 ./configure --prefix="$PREFIX"
 make -j4
 make install
@@ -48,32 +57,16 @@ cd ..
 
 which ldconfig && ldconfig || true
 
+# make sure to find our libsodium
+export PKG_CONFIG_PATH=$PREFIX/lib/pkgconfig
+
 tar -xzf zeromq-${LIBZMQ_VERSION}.tar.gz
 cd zeromq-${LIBZMQ_VERSION}
-# patch CURVE crash bug https://github.com/zeromq/libzmq/issues/4241
-# FIXME: switch to `--disable-libsodium_randombytes_close`
-# when we bump bundle libzmq to 4.3.5
-
-patch -p1 <<EOF
-diff --git a/src/random.cpp b/src/random.cpp
-index 17c3537df3..12dead87ba 100644
---- a/src/random.cpp
-+++ b/src/random.cpp
-@@ -151,8 +151,6 @@ static void manage_random (bool init_)
-     if (init_) {
-         int rc = sodium_init ();
-         zmq_assert (rc != -1);
--    } else {
--        randombytes_close ();
-     }
- #else
-     LIBZMQ_UNUSED (init_);
-EOF
-
+cp LICENSE "${LICENSE_DIR}/LICENSE.zeromq.txt"
 # avoid error on warning
 export CXXFLAGS="-Wno-error ${CXXFLAGS:-}"
 
-./configure --prefix="$PREFIX" --with-libsodium
+./configure --prefix="$PREFIX" --disable-perf --without-docs --enable-curve --with-libsodium --disable-drafts --disable-libsodium_randombytes_close
 make -j4
 make install
 
